==> haskell-unixutils-1.54.1-77-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-9ITFNU7MXHmI5H2SUr4hrn
key: Unixutils-1.54.1-9ITFNU7MXHmI5H2SUr4hrn
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: dec263fccea7486c16a346f53ba6a344
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.6.4/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-9ITFNU7MXHmI5H2SUr4hrn
extra-libraries:
    crypt
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.1-7nkghZ77rTO8NZKanvk3XU filepath-1.4.2.1 mtl-2.2.2
    process-1.6.5.0 process-extras-0.7.4-To8LGnalHnGruUrs8fJtu
    pureMD5-2.1.3-JkARNtMpohK2vdX1mkpvUi
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37 unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.1-78-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Unixutils
version: 1.54.1
id: Unixutils-1.54.1-JlHa2m4VfJp8TfX1WlunP
key: Unixutils-1.54.1-JlHa2m4VfJp8TfX1WlunP
license: BSD-3-Clause
maintainer: jeremy@n-heptane.com
author: Jeremy Shaw, David Fox
homepage: https://github.com/seereason/haskell-unixutils.git
synopsis: A crude interface between Haskell and Unix-like operating systems
description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.
category: System
abi: 3acff21f348c77deff9a6441a5efda9f
exposed: True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice
import-dirs: /usr/lib/ghc-8.6.4/site-local/Unixutils-1.54.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/Unixutils-1.54.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/Unixutils-1.54.1
hs-libraries: HSUnixutils-1.54.1-JlHa2m4VfJp8TfX1WlunP
extra-libraries:
    crypt
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.1-CTCpiJ1kUxgIR315GHArm5 filepath-1.4.2.1 mtl-2.2.2
    process-1.6.5.0 process-extras-0.7.4-RqOT2uDUXp4XNZNrBa2oy
    pureMD5-2.1.3-JkARNtMpohK2vdX1mkpvUi
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37 unix-2.7.2.2
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html: /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
